@@ -1,4 +1,4 @@
-/* $Id: filter.c,v 1.1.1.1.2.1 2003/04/25 22:57:47 cegger Exp $
+/* $Id: filter.c,v 1.4 2003/10/22 15:45:45 cegger Exp $
 ******************************************************************************
 
    filter.c - sample code to demonstrate filter usage
@@ -26,17 +26,18 @@
 ******************************************************************************
 */
 
+/* Include the LibGII declarations.
+ */
+#include <ggi/gii.h>
+
 /* Include the necessary headers used for e.g. error-reporting.
  */
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-/* Include the LibGII declarations.
- */
-#include <ggi/gii.h>
 
-void test_showevent(gii_event *ev)
+static void test_showevent(gii_event *ev)
 {
 	unsigned int y;
 	
@@ -77,7 +78,7 @@ void test_showevent(gii_event *ev)
 	}
 }
 
-void test_gii_poll(gii_input_t inp, struct timeval *tval)
+static void test_gii_poll(gii_input_t inp, struct timeval *tval)
 {
 	gii_event_mask	mask;
 	gii_event	event;
