@@ -1,4 +1,4 @@
-/* $Id: filter.c,v 1.6 2002/02/22 21:51:04 soyt Exp $
+/* $Id: filter.c,v 1.10.4.1 2004/11/10 21:36:41 cegger Exp $
 ******************************************************************************
 
    Filter-keytrans - generic key event translator.
@@ -31,6 +31,7 @@
 #include "config.h"
 #include <ggi/internal/gii-dl.h>
 #include <ggi/internal/gii_debug.h>
+#include <ggi/internal/gii_target.h>
 
 static void send_devinfo(gii_input *inp);
 
@@ -132,7 +133,9 @@ static void send_devinfo(gii_input *inp)
 {
 	gii_event ev;
 	gii_cmddata_getdevinfo *dinfo;
-	int size = sizeof(gii_cmd_nodata_event)+sizeof(gii_cmddata_getdevinfo);
+	size_t size;
+
+	size = sizeof(gii_cmd_nodata_event)+sizeof(gii_cmddata_getdevinfo);
 
 	_giiEventBlank(&ev, size);
 	
@@ -159,7 +162,7 @@ static int fkey_doload(const char *filename,fkey_priv *priv) {
 		return GGI_ENOFILE;
 	}
 	while(fgets(buffer,2048,infile)) {
-		if ( 10 != sscanf(buffer,"%i %i %i %i %i %i %i %i %i %i",
+		if ( 10 != sscanf(buffer,"%u %u %u %u %u %u %u %u %u %u",
 			&mapbuf.modifier_mask,
 			&mapbuf.modifier_value,
 			&mapbuf.buttonin,
@@ -223,6 +226,7 @@ static int fkey_loadmap(const char *args,fkey_priv *priv) {
 	return 1;	/* Failure */
 }
 
+
 int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 {
 	fkey_priv   *priv;
