@@ -1,4 +1,4 @@
-/* $Id: filter.c,v 1.6.2.2 2003/10/05 08:12:23 cegger Exp $
+/* $Id: filter.c,v 1.13.4.1 2004/11/14 13:07:43 cegger Exp $
 ******************************************************************************
 
    Filter-mouse - generic mouse event translaator.
@@ -25,14 +25,19 @@
 ******************************************************************************
 */
 
+#include "config.h"
 #include <math.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 
-#include "config.h"
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+
 #include <ggi/internal/gii-dl.h>
 #include <ggi/internal/gii_debug.h>
+#include <ggi/internal/gii_target.h>
 
 static void send_devinfo(gii_input *inp);
 
@@ -45,7 +50,7 @@ enum maptype {
 	MAP_END
 };
 
-const char *maptypelist[MAP_END]={
+static const char *maptypelist[MAP_END]={
 	"KEY",
 	"REL",
 	"ABS",
@@ -61,7 +66,7 @@ enum axis {
 	AX_END
 };
 
-const char *axislist[AX_END]={
+static const char *axislist[AX_END]={
 	"X",
 	"Y",
 	"Z",
@@ -99,8 +104,7 @@ typedef struct {
 	uint32 modifiers;
 } fmouse_priv;
 
-static void
-fmouse_send_pbutton(gii_input *inp, uint8 type, uint32 nr)
+static void fmouse_send_pbutton(gii_input *inp, uint8 type, uint32 nr)
 {
 	gii_event ev;
 
@@ -127,16 +131,16 @@ static sint32 getaxis(gii_pmove_event *move,enum axis axis) {
 
 static void setaxis(gii_pmove_event *move,enum axis axis,sint32 value) {
 	switch(axis) {
-		case AX_X:	move->x=value;break;
-		case AX_Y:	move->y=value;break;
-		case AX_Z: 	move->z=value;break;
-		case AX_WHEEL:	move->wheel=value;break;
-		default:	return;
+	case AX_X:	move->x=value;break;
+	case AX_Y:	move->y=value;break;
+	case AX_Z: 	move->z=value;break;
+	case AX_WHEEL:	move->wheel=value;break;
+	default:	return;
 	}
 }
 
 static sint32 gettrans(struct transform *tf,double invalue) {
-	return invalue*tf->factor+
+	return invalue * tf->factor +
 		((fabs(invalue)>tf->treshold) ? (invalue > 0.0 ? invalue-tf->treshold : invalue+tf->treshold)*tf->higher : 0) ;
 }
 
@@ -235,21 +239,29 @@ GII_fmouse_handler(gii_input *inp, gii_event *event)
 		}
 		switch(entry->to) {
 			case MAP_REL:
-				setaxis(&pmrel,entry->todata.trans.axis,gettrans(&entry->todata.trans,invalue));
+				setaxis(&pmrel, 
+					entry->todata.trans.axis, 
+					gettrans(&entry->todata.trans,
+						(double)invalue));
 				ret=1;has|=HASREL;
 				break;
 			case MAP_ABS:
-				setaxis(&pmabs,entry->todata.trans.axis,gettrans(&entry->todata.trans,invalue));
-				ret=1;has|=HASABS;
+				setaxis(&pmabs, 
+					entry->todata.trans.axis, 
+					gettrans(&entry->todata.trans, 
+						(double)invalue));
+				ret = 1;
+				has |= HASABS;
 				break;
 			case MAP_BUTTON:
 				fmouse_send_pbutton(inp, 
 					invalue ? evPtrButtonPress :
-						evPtrButtonRelease, 
+						evPtrButtonRelease,
 					entry->todata.button);
-				ret=1;
+				ret = 1;
 				break;
-			default:continue; /* Something is WRONG here. */
+			default:
+				continue; /* Something is WRONG here. */
 		}
 	}
 	GIIDPRINT_MISC("filter-mouse: Checking entry %p.\n",entry);
@@ -298,7 +310,9 @@ static void send_devinfo(gii_input *inp)
 {
 	gii_event ev;
 	gii_cmddata_getdevinfo *dinfo;
-	int size = sizeof(gii_cmd_nodata_event)+sizeof(gii_cmddata_getdevinfo);
+	size_t size;
+
+	size = sizeof(gii_cmd_nodata_event)+sizeof(gii_cmddata_getdevinfo);
 
 	_giiEventBlank(&ev, size);
 	
@@ -325,7 +339,7 @@ static int checkkeyword(char *str,char **endptr,const char *list[],int numlist)
 			return x;
 		}
 	}
-	return -1;
+	return GGI_ENOMATCH;
 }
 
 static int fmouse_doload(const char *filename,fmouse_priv *priv) {
@@ -460,6 +474,7 @@ static int fmouse_loadmap(const char *args,fmouse_priv *priv) {
 	return 1;	/* Failure */
 }
 
+
 int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 {
 	fmouse_priv   *priv;
