@@ -1,4 +1,4 @@
-/* $Id: conf.c,v 1.1.1.1.2.2 2004/05/17 05:56:29 cegger Exp $
+/* $Id: conf.c,v 1.11 2004/09/10 10:05:18 pekberg Exp $
 ******************************************************************************
   
    LibGG - Configuration handling
@@ -56,6 +56,12 @@ _ggDoLoad(const char *file, gg_dlconfig **list, int incl, char *oldroot)
 	FILE *inf;
 	char root[2048], line[2048], buff[2048], *cp, *bp;
 	char *name, *fname;
+	const char *fp;
+#if CHAR_DIRDELIM != '/'
+	const char *fp2;
+#endif
+	char tmp;
+	size_t fname_len;
 	gg_dlconfig *dltmp, *dlconf;
 	root[0] = '\0';
 
@@ -65,24 +71,42 @@ _ggDoLoad(const char *file, gg_dlconfig **list, int incl, char *oldroot)
 	dlconf = *list;
 
 	if (oldroot) {
-		strncpy(root, oldroot, 2047);
-		root[2047] = '\0';
+		ggstrlcpy(root, oldroot, sizeof(root));
 	}
 
 	while (fgets(line, 2048, inf)) {
 		cp = line;
 
 		while (isspace((int)*cp)) cp++;
-		if (*cp == '\0' || *cp == '#')
+		if (*cp == '\0' || *cp == '#' || *cp == '\n')
 			continue;
-	
+
 		if (strncmp(cp, ".root:", 6) == 0) {
 			cp += 6;
 			while (isspace((int)*cp)) cp++;
 			name = cp;
 			while (*cp && !isspace((int)*cp)) cp++;
-			strncpy(root, name, cp-name);
-			root[cp-name] = '\0';
+			/* The .root '*' is special and denotes an alias
+			 * expansion section.
+			 */
+			if (*name == '/' || *name == '*')
+				ggstrlcpy(root, name, (size_t)(cp - name + 1));
+			else {
+				fp = strrchr(file, '/');
+				if (fp == NULL)  fp  = file;
+#if CHAR_DIRDELIM != '/'
+				fp2 = strrchr(file, CHAR_DIRDELIM);
+				if (fp2 == NULL) fp2 = file;
+				if (fp < fp2)
+					fp = fp2;
+#endif
+				if (fp != file)
+					++fp;
+				ggstrlcpy(root, file, (size_t)(fp - file + 1));
+				tmp = *cp; *cp = '\0';
+				ggstrlcat(root, name, sizeof(root));
+				*cp = tmp;
+			}
 			continue;
 		}
 		if (strncmp(cp, ".include", 8) == 0) {
@@ -90,8 +114,24 @@ _ggDoLoad(const char *file, gg_dlconfig **list, int incl, char *oldroot)
 			while (isspace((int)*cp)) cp++;
 			name = cp;
 			while (*cp && !isspace((int)*cp)) cp++;
-			strncpy(buff, name, cp-name);
-			buff[cp-name] = '\0';
+			if (*name == '/')
+				ggstrlcpy(buff, name, (size_t)(cp - name + 1));
+			else {
+				fp = strrchr(file, '/');
+				if (fp == NULL)  fp  = file;
+#if CHAR_DIRDELIM != '/'
+				fp2 = strrchr(file, CHAR_DIRDELIM);
+				if (fp2 == NULL) fp2 = file;
+				if (fp < fp2)
+					fp = fp2;
+#endif
+				if (fp != file)
+					++fp;
+				ggstrlcpy(buff, file, (size_t)(fp - file + 1));
+				tmp = *cp; *cp = '\0';
+				ggstrlcat(buff, name, sizeof(buff));
+				*cp = tmp;
+			}
 			if (incl+1 < 20) {
 				*list = dlconf;
 				_ggDoLoad(buff, list, incl+1,
@@ -102,34 +142,32 @@ _ggDoLoad(const char *file, gg_dlconfig **list, int incl, char *oldroot)
 				fprintf(stderr,"libgg: .include recursion "
 						"too deep\n");
 			}
+			continue;
 		}	
 		bp = buff;
-		while (!isspace((int)*cp)) *(bp++) = *(cp++);
+		while (*cp && !isspace((int)*cp)) *(bp++) = *(cp++);
 		*(bp) = '\0';
 		if ((name = strdup(buff)) == NULL) {
 			return GGI_ENOMEM;
 		}
 		while (isspace((int)*cp)) cp++;
-		if (*cp == '\0' || *cp == '#') {
+		if (*cp == '\0' || *cp == '#' || *cp == '\n') {
 			free(name);
 			continue;
 		}
 		bp=buff;
-		while (!isspace((int)*cp)) {
-			*(bp++) =* (cp++);
-		}
+		while (*cp && !isspace((int)*cp)) *(bp++) =* (cp++);
 		*(bp) = '\0';
 		if (buff[0] != CHAR_DIRDELIM) {
-			if ((fname = (char *) malloc(strlen(buff)
-						     +strlen(root)
-						     +strlen(STRING_DIRDELIM)
-						     +1))
-			    == NULL) {
+			fname_len = strlen(buff) + strlen(root)
+				+ strlen(STRING_DIRDELIM) + 1;
+			fname = (char *) malloc(fname_len);
+			if (fname == NULL) {
 				return GGI_ENOMEM;
 			}
-			strcpy(fname,root);
-			strcat(fname,STRING_DIRDELIM);
-			strcat(fname,buff);
+			ggstrlcpy(fname, root, fname_len);
+			ggstrlcat(fname,STRING_DIRDELIM, fname_len);
+			ggstrlcat(fname,buff, fname_len);
 		} else {
 			if ((fname = strdup(buff)) == NULL) {
 				return GGI_ENOMEM;
@@ -154,7 +192,7 @@ _ggDoLoad(const char *file, gg_dlconfig **list, int incl, char *oldroot)
 			if (*cp == '\0' || *cp == '#') 
 				break;
 			bp = buff;
-			while (!isspace((int)*cp)) *(bp++) = *(cp++);
+			while (*cp && !isspace((int)*cp)) *(bp++) = *(cp++);
 			*(bp) = '\0';
 			if ((vtmp = (gg_string_list *)malloc(sizeof(gg_string_list)))
 			    == NULL 
@@ -260,15 +298,21 @@ int ggConfigExpandAlias(void *confhandle, const char *list_in,
 		newcur=ggParseTarget(current,buffer,sizeof(buffer));
 		if (NULL==newcur) return GGI_EARGINVAL;
 		match=ggMatchConfig(confhandle, buffer, NULL);
-		if (match&&match[0]=='*') {
+		if (match && match[0]=='*') {
 			if (loopcnt++>100) return GGI_EARGINVAL; /* FIXME ELOOP */
-			matchlen=strlen(match+2);
-			if (outremain+newcur-current-matchlen>0) {
-				 memmove(current+matchlen,newcur,strlen(newcur)+1);
-				 memcpy(current,match+2,matchlen);
-				 outremain+=newcur-current-matchlen-1;
-			} else return GGI_ENOMEM;
-		} else current=newcur;
+			matchlen = strlen(match + 2);
+			if ((outremain + newcur - current - matchlen) > 0) {
+				 memmove(current + matchlen,
+					newcur,strlen(newcur)+1);
+				 memcpy(current, match+2,
+					(unsigned)matchlen);
+				 outremain += newcur - current - matchlen - 1;
+			} else {
+				return GGI_ENOMEM;
+			}
+		} else {
+			current = newcur;
+		}
 	}
 	return 0;
 }
