@@ -1,4 +1,4 @@
-/* $Id: misc.c,v 1.7 2002/11/02 13:18:29 cegger Exp $
+/* $Id: misc.c,v 1.20 2004/08/05 13:47:28 cegger Exp $
 ******************************************************************************
 
    LibGG - Misc utility functions
@@ -25,22 +25,18 @@
 ******************************************************************************
 */
 
+#include "plat.h"
 #include <stdlib.h>
 #include <string.h>
 #include <limits.h>
 
 #include <ggi/gg.h>
-#include "plat.h"
 
-#ifndef PATH_MAX
-# ifdef _POSIX_PATH_MAX
-#  define PATH_MAX _POSIX_PATH_MAX
-# else
-#  define PATH_MAX 4096 /* Should be enough for most systems */
-# endif
-#endif
+#if defined(__WIN32__) && !defined(__CYGWIN__)
+#include "misc_win32.c"
+#endif /* __WIN32__ && !__CYGWIN__ */
 
-/* FIXME - make win32 and other systems do the right thing here */
+/* FIXME - make unknown systems do the right thing here */
 
 #define APPENDNAME	"/.ggi"
 #define APPENDLEN	5
@@ -49,21 +45,30 @@ const char *ggGetUserDir(void)
 {
 	static char curpath[PATH_MAX+1];
 	char *ptr;
-	int len;
+	size_t len;
+	int need_ptr2free = 0;
+
+	ggLock(_gg_global_mutex);
+
+	if (curpath[0] != '\0') {
+		/* The user dir has already been calculated */
+		ggUnlock(_gg_global_mutex);
+		return curpath;
+	}
 
 	ptr = getenv("HOME");
+
 	if (ptr == NULL) {
 		/* hmm... $HOME is not there... */
 
-
 #ifndef HAVE_TMP_PATH
 
-#if defined(macintosh) || (defined(__MACH__) && defined(__APPLE__))
+#if defined(macintosh) || defined(__darwin__)
 #define HAVE_TMP_PATH
 		/* Darwin 6.x */
 		const char *uid = getenv("UID");
-		ptr = malloc(strlen(uid) + strlen("/tmp//Temporary Items")+1);
-		sprintf(ptr, "/tmp/%s/Temporary Items", uid);
+		asprintf(&ptr, "/tmp/%s/Temporary Items", uid);
+		need_ptr2free = 1;
 
 #endif	/* MAC OS / DARWIN */
 
@@ -72,7 +77,7 @@ const char *ggGetUserDir(void)
 
 #ifndef HAVE_TMP_PATH
 
-#if defined(_POSIX_SOURCE)
+#if defined(_POSIX_SOURCE) || defined(_POSIX_C_SOURCE)
 #define HAVE_TMP_PATH
 		/* this hopefully catches all unix environments */
 		ptr = "/tmp";
@@ -87,8 +92,14 @@ const char *ggGetUserDir(void)
 #if defined(__WIN32__) && !defined(__CYGWIN__)
 #define HAVE_TMP_PATH
 		/* Should catch all win32 platforms */
-#error Set ptr to an appropriate common default path for win32 platforms.
-#endif	/* __WIN32__ */
+		if (ptr == NULL)
+			ptr = get_personal_folder_path();
+		if (ptr == NULL)
+			ptr = getenv("TMP");
+		if (ptr == NULL)
+			ptr = getenv("TEMP");
+
+#endif	/* __WIN32__ && !__CYGWIN__ */
 
 #endif
 
@@ -102,19 +113,13 @@ const char *ggGetUserDir(void)
 	len = strlen(ptr);
 	if (len + APPENDLEN > PATH_MAX) return NULL;
 
-	/* Must lock here */
-	ggLock(_gg_global_mutex);
-	strcpy(curpath, ptr);
-	strcpy(curpath+len, APPENDNAME);
+	ggstrlcpy(curpath, ptr, sizeof(curpath));
+	ggstrlcpy(curpath+len, APPENDNAME, sizeof(curpath) - len);
 	ggUnlock(_gg_global_mutex);
 
+	if (need_ptr2free) {
+		free(ptr);
+	}
+
 	return curpath;
 }
-
-#ifndef GG_USLEEP_DEFINED
-#error You need to implement ggUSleep() for this system
-#endif
-
-#ifndef GG_CURTIME_DEFINED
-#error You need to implement ggCurTime() for this system
-#endif
