@@ -1,4 +1,4 @@
-/* $Id: plat.h,v 1.11.2.4 2003/10/05 08:15:25 cegger Exp $
+/* $Id: plat.h,v 1.27.4.2 2004/11/11 19:07:46 cegger Exp $
 ******************************************************************************
 
    LibGG internal definitions
@@ -28,13 +28,17 @@
 #ifndef _GG_INTERNAL_PLAT_H
 #define _GG_INTERNAL_PLAT_H
 
-#include <ggi/system.h>
 #include "config.h"
+#include <ggi/system.h>
 
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
 #endif
 
+#ifdef HAVE_LIMITS_H
+# include <limits.h>
+#endif
+
 /* Mutex for protecting LibGG global data */
 extern void	*_gg_global_mutex;
 
@@ -42,6 +46,17 @@ extern void	*_gg_global_mutex;
 # define inline __inline__
 #endif
 
+#if (defined(__SVR4) || defined(__svr4) || defined(SVR4) \
+	|| defined(svr4) || defined(__SYSTYPE_SVR4) || defined(__hpux__)) \
+	&& !defined(__svr4__)
+# define __svr4__	1
+#endif
+
+#if (defined(__APPLE__) && defined(__MACH__)) && !defined(__darwin__)
+# define __darwin__	1
+#endif
+
+
 #if defined(__WIN32__) && !defined(__CYGWIN__)
 # define CHAR_DIRDELIM '\\'
 # define STRING_DIRDELIM "\\"
@@ -51,14 +66,25 @@ extern void	*_gg_global_mutex;
 #endif
 
 
-#ifndef _POSIX_SOURCE
+#if !defined(PATH_MAX)
+# ifdef _POSIX_PATH_MAX
+#  define PATH_MAX _POSIX_PATH_MAX
+# else
+#  define PATH_MAX 4096 /* Should be enough for most systems */
+# endif
+#endif
+
+
+#if !defined(_POSIX_SOURCE)
+
 /* *BSD system */
-# if defined(__OpenBSD__) || defined(__NetBSD__) || defined(__FreeBSD__)
-#   define _POSIX_SOURCE
+# if defined(__OpenBSD__) || defined(__NetBSD__) || defined(__FreeBSD__) \
+	|| defined(__DragonFly__)
+#   define _POSIX_C_SOURCE	199506L
 # endif
 
-/* Solaris */
-# if defined(sun)
+/* SYSTEM V Release IV systems (almost all commercial unices) */
+# if defined(__svr4__)
 #   define _POSIX_SOURCE
 # endif
 
@@ -67,8 +93,11 @@ extern void	*_gg_global_mutex;
 #   define _POSIX_SOURCE
 # endif
 
-#endif
+#endif	/* _POSIX_SOURCE && _POSIX_C_SOURCE */
 
+#if defined(_POSIX_C_SOURCE)
+#   define _XOPEN_SOURCE	600
+#endif
 
 
 #ifndef HAVE_ARCH
@@ -76,11 +105,24 @@ extern void	*_gg_global_mutex;
 #if defined(__WIN32__) && !defined(__CYGWIN__)
 #define HAVE_ARCH
 # include <windows.h>
-# define GGOPENLIB(filename)	LoadLibrary((filename))
+# define GGOPENLIB(filename)	ggWin32DLOpen((filename))
 # define GGOPENLIBGLOBAL(filename) GGOPENLIB(filename)
 # define GGGETSYM(handle,sym)	GetProcAddress((handle),(sym))
 # define GGCLOSELIB(handle)	FreeLibrary((handle))
-# define GGDLERROR()		NULL
+# define GGDLERROR()		ggWin32DLError()
+
+/* forward declarations
+ */
+
+#include <ggi/gg.h>
+
+__BEGIN_DECLS
+
+gg_module ggWin32DLOpen(const char *filename);
+const char *ggWin32DLError(void);
+
+__END_DECLS
+
 #endif	/* __WIN32__ */
 
 #endif
@@ -88,7 +130,7 @@ extern void	*_gg_global_mutex;
 
 #ifndef HAVE_ARCH
 
-#if defined(macintosh) || (defined(__MACH__) && defined(__APPLE__))
+#if defined(macintosh) || defined(__darwin__)
 # define HAVE_ARCH
 # ifdef HAVE_MACH_O_DYLD_H
 #  include <mach-o/dyld.h>
@@ -122,7 +164,7 @@ __END_DECLS
 
 #ifndef HAVE_ARCH
 
-#if defined(_POSIX_SOURCE)
+#if defined(HAVE_DLOPEN)
 #define HAVE_ARCH
 /* should catch all unix system with a native dlopen() implementation
  */
