@@ -1,4 +1,4 @@
-/* $Id: gii.c,v 1.11.2.4 2003/11/13 21:50:27 cegger Exp $
+/* $Id: gii.c,v 1.30.2.1 2004/11/14 13:08:58 cegger Exp $
 ******************************************************************************
 
    Graphics library for GGI. General Input Interface.
@@ -40,6 +40,10 @@
 #include <string.h>
 #include <ctype.h>
 
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+
 #ifdef HAVE_SIGNAL_H
 #include <signal.h>
 #endif
@@ -53,8 +57,40 @@
 static uint32	_gii_origin_count = GII_MAXSUBLIBS;
 
 
-/* Macros */
-#define GII_EV_TIMESTAMP(ev)	ggCurTime(&((ev)->any.time))
+/*
+******************************************************************************
+ Internal helpers
+******************************************************************************
+*/
+
+/* Make event timestamps strictly monotonic.
+ */
+static inline void
+_GII_ev_timestamp(gii_event *ev)
+{
+	static struct timeval last_event = { 0, 0 };
+
+	if(_gii_threadsafe)
+		ggLock(_gii_event_lock);
+
+	ggCurTime(&(ev->any.time));
+	if((ev->any.time.tv_sec > last_event.tv_sec)
+	   || ((ev->any.time.tv_sec == last_event.tv_sec)
+	       && (ev->any.time.tv_usec > last_event.tv_usec)))
+	{
+		last_event = ev->any.time;
+	}
+	else {
+		if(++last_event.tv_usec >= 1000000) {
+			last_event.tv_usec -= 1000000;
+			++last_event.tv_sec;
+		}
+		ev->any.time = last_event;
+	}
+
+	if(_gii_threadsafe)
+		ggUnlock(_gii_event_lock);
+}
 
 
 /*
@@ -172,7 +208,7 @@ static inline int
 _giiAddEvent(gii_ev_queue *qp, gii_event *ev)
 {
 	if (qp->head < qp->tail) {
-		if ((qp->tail - qp->head - 1) < ev->size) {
+		if ((unsigned)(qp->tail - qp->head - 1) < ev->size) {
 			return GGI_EEVOVERFLOW;
 		}	
 	} else if (qp->head > qp->tail) {
@@ -202,6 +238,10 @@ _giiAddEvent(gii_ev_queue *qp, gii_event *ev)
 
 
 /* Peek at event at tail of queue
+ * WARNING: The returned pointer may be misaligned.
+ *   Use it in conjunction with memcpy(3) to ensure
+ *   aligned memory access.
+ *   Some platforms (i.e. NetBSD/sparc64) rely on this.
  */
 static inline gii_event *
 _giiPeekEvent(gii_ev_queue *qp)
@@ -284,9 +324,15 @@ _giiEvQueueRelease(gii_input *inp, gii_event *ev, gii_event_mask mask)
 				       inp->queue->queues[queue]));
 		qp_tmp = inp->queue->queues[queue];
 		if (qp_tmp && qp_tmp->count && (evm & (1 << queue))) {
-			gii_event *e_tmp = (gii_event *)
-				(qp_tmp->buf + qp_tmp->tail);
-			struct timeval t_tmp = e_tmp->any.time;
+			uint8 *e_tmp = (uint8 *)_giiPeekEvent(qp_tmp);
+			struct timeval t_tmp;
+
+			/* Assure aligned memory access. Some platforms
+			 * (i.e. NetBSD/sparc64) rely on this.
+			 */
+			memcpy(&t_tmp,
+				e_tmp + ((int)&(((gii_event*)0)->any.time)),
+				sizeof(struct timeval));
 
 			if (t_tmp.tv_sec < t_min.tv_sec || 
 			    (t_tmp.tv_sec == t_min.tv_sec &&
@@ -343,7 +389,7 @@ static void _giiSetQueue(struct gii_input *inp, struct gii_input *set)
 
 /* Set up an event
  */
-void _giiEventBlank(gii_event *ev, int size)
+void _giiEventBlank(gii_event *ev, size_t size)
 {
 	memset(ev, 0, size);
 
@@ -351,10 +397,73 @@ void _giiEventBlank(gii_event *ev, int size)
 	ev->any.origin = GII_EV_ORIGIN_NONE;
 	ev->any.target = GII_EV_TARGET_ALL;
 
-	GII_EV_TIMESTAMP(ev);
+	_GII_ev_timestamp(ev);
 }
 
 
+
+/* Default devinfo sender
+ * Most input targets implement the devinfo sender in this way.
+ */
+int _giiStdSendDevInfo(gii_input *inp, gii_cmddata_getdevinfo *data)
+{
+	gii_event ev;
+	gii_cmddata_getdevinfo *dinfo;
+
+	int size = sizeof(gii_cmd_nodata_event) +
+			sizeof(gii_cmddata_getdevinfo);
+
+	GIIDPRINT_EVENTS("_giiStdSendDevInfo(%p, %p\n)", inp, data);
+
+	_giiEventBlank(&ev, size);
+
+	ev.any.size	= size;
+	ev.any.type	= evCommand;
+	ev.any.origin	= inp->origin;
+	ev.cmd.code	= GII_CMDCODE_GETDEVINFO;
+
+	dinfo = (gii_cmddata_getdevinfo *) ev.cmd.data;
+	*dinfo = *data;
+
+	return _giiEvQueueAdd(inp, &ev);
+}	/* _giiStdSendDevInfo */
+
+
+
+/* Default valuator sender
+ * Most input targets implement the valuator sender in this way.
+ */
+int _giiStdSendValEvent(gii_input *inp, gii_cmddata_getvalinfo *vi,
+			int val, int maxval)
+{
+	gii_cmddata_getvalinfo *VI = NULL;
+	gii_event ev;
+	size_t size;
+
+	GIIDPRINT_EVENTS("_giiStdSendValEvent(%p, %p, %i, %i) called\n",
+			inp, VI, val, maxval);
+
+	if (val >= maxval) return GGI_EARGINVAL;
+
+	size = sizeof(gii_cmd_nodata_event) +
+			sizeof(gii_cmddata_getvalinfo);
+
+	_giiEventBlank(&ev, size);
+
+	ev.any.size	= size;
+	ev.any.type	= evCommand;
+	ev.any.origin	= inp->origin;
+	ev.cmd.code	= GII_CMDCODE_GETVALINFO;
+
+	VI = (gii_cmddata_getvalinfo *) ev.cmd.data;
+
+	*VI = vi[val];
+
+	return _giiEvQueueAdd(inp, &ev);
+}	/* _giiStdSendValEvent */
+
+
+
 /* Add an event. Return 0 on either success or unrecognized event type,
    return GGI_ENOMEM if the queue can't be allocated, and GGI_EEVOVERFLOW if
    the queue is full.
@@ -597,48 +706,72 @@ uint32 _giiRegisterDevice(gii_input *inp,
 			  gii_cmddata_getdevinfo  *dev,
 			  gii_cmddata_getvalinfo  *val) {
 	gii_deviceinfo * ret;
+
+	if(inp->devinfo)
+		if ((inp->devinfo->origin & GII_SUBLIBMASK) == GII_SUBLIBMASK)
+			/* 
+			   Too many devices registered.
+			   
+			   FIXME: This can actually be incorrect,
+			   since other devices may have been
+			   unregistered, leaving space in the device
+			   count for this one.  We should scan the
+			   devices and try to insert the new one.
+			   (devices *must* then be sorted).
+			   
+			   But hey, do we really expect to exhaust 256
+			   devices this way?
+			*/
+			return 0;
 	
 	ret = calloc(1, sizeof(*ret));
-	if (ret != NULL) {
-		ret->dev=dev;
-		ret->val=val;
-		/* The first dev always has the highest origin */
-		if(inp->devinfo==NULL)
-			ret->origin=inp->origin;
-		else
-			ret->origin=inp->devinfo->origin+1;
-		ret->next=inp->devinfo;
-		inp->devinfo=ret;
-		return ret->origin;
-	}
-	return 0;
+	if (ret == NULL) return 0;
+	
+	ret->dev = dev;
+	ret->val = val;
+	
+	if(inp->devinfo == NULL)
+		/* Device count start as 1, to keep origin designate
+		   the whole input. */
+		ret->origin = inp->origin + 1;
+	else
+		ret->origin = inp->devinfo->origin + 1;
+	ret->next = inp->devinfo;
+	inp->devinfo = ret;
+	
+	return ret->origin;
 }
 
-/* Remove a device given by its origin.
+
+/*
+  Remove a device given by its origin.
+  
+  return GGI_OK, or GGI_ENOTFOUND if no device match the origin.
+  
  */
 int _giiUnregisterDevice(gii_input *inp, uint32 origin) {
 
 	gii_deviceinfo *t, *curr;
 	
-	if(inp->devinfo==NULL) return -1;
+	if(inp->devinfo == NULL) return GGI_ENOTFOUND;
 	
-	if(inp->devinfo->origin==origin) {
-		t=inp->devinfo;
-		inp->devinfo=inp->devinfo->next;
+	if(inp->devinfo->origin == origin) {
+		t = inp->devinfo;
+		inp->devinfo = inp->devinfo->next;
 		free(t);
-		return 0;
+		return GGI_OK;
 	}
-	curr=inp->devinfo;
+	curr = inp->devinfo;
 	while(curr->next) {
-		if(curr->next->origin==origin) {
-			t=curr->next;
-			curr->next=curr->next->next;
+		if(curr->next->origin == origin) {
+			t = curr->next;
+			curr->next = curr->next->next;
 			free(t);
-			return 0;
+			return GGI_OK;
 		}
 		curr=curr->next;
 	}
-	return -1;
+	return GGI_ENOTFOUND;
 }
 
 /*
@@ -706,7 +839,7 @@ struct gii_input *giiOpen(const char *input,...)
 		if (inp->dlhand == NULL) {
 			_giiInputFree(inp);
 		} else {
-			giifunc_inputinit *init = inp->dlhand->init;
+			giifunc_inputinit *init = (giifunc_inputinit *)inp->dlhand->init;
 			err = init(inp, args, argptr);
 			GIIDPRINT_LIBS("%d=dlh->init(%p,\"%s\",%p) - %s\n",
 				       err, inp, args, argptr, target);
@@ -844,6 +977,7 @@ int giiSplitInputs(struct gii_input *inp, struct gii_input **newhand,
 		   uint32 origin, uint32 flags)
 {
 	struct gii_input *idx;
+	gii_deviceinfo   *di;
 
 	flags = 0; /* Silence, GCC!  Flags is reserved for later use 
 		      when asking an input driver-lib to split off an 
@@ -864,110 +998,122 @@ int giiSplitInputs(struct gii_input *inp, struct gii_input **newhand,
 	}
 
 	idx = inp;
+	if (origin == GII_EV_ORIGIN_NONE) goto haveit;
 	do {
 		/* walk the queue until the right origin is found. */
 
-		if ((origin == idx->origin) || 
-		    (origin == GII_EV_ORIGIN_NONE)) {
+		if ( (idx->origin&GII_MAINMASK) != (origin&GII_MAINMASK) ) 
+			goto trynextone;
 
-			if (inp == idx) {
-				/* Ooops - we try to split off the _first_ input. This is a special case.
-				 */
+		if (origin == idx->origin) 
+			goto haveit;
 
-				/* Make a new queue for me. Old is 
-				 * retained due to pointers in other inputs. 
-				 */
-				_giiEvQueueAllocate(inp); 
-				inp->safequeue = NULL;
-				if (inp->cache != NULL) {
-					inp->cache->count--;
-					if (inp->cache->count == 0) 
-						_giiCacheFree(inp->cache);
-					inp->cache = _giiCacheAlloc();
-					inp->cache->count++;
-				}
+		for (di=idx->devinfo;di;di=di->next)
+			if (di->origin==origin)
+				goto haveit;
 
-				/* lock adjacent inputs as they will be changed now (relink) */
-				if (_gii_threadsafe) {
-					ggLock(inp->next->mutex);
-					if (inp->next != inp->prev)
-						ggLock(inp->prev->mutex);
-				}
-				inp->next->prev = inp->prev;
-				inp->prev->next = inp->next;
-				*newhand = inp->next;
-				_giiUpdateCache(*newhand);
-				/* unlock adjacent inputs again. */
-				if (_gii_threadsafe) {
-					if (inp->next != inp->prev)
-						ggUnlock(inp->prev->mutex);
-					ggUnlock(inp->next->mutex);
-					/* Look closely:
-					 * inp->queue has been overwritten during 
-					 * _giiEvQueueAllocate(inp); However 
-					 * inp->queue->mutex ist still locked.
-					 * inp->next->queue has a copy of the old 
-					 * contents of inp->queue, so we use that.
-					 */
-					ggUnlock(inp->next->queue->mutex);
-				}
-				/* selflink myself. */
-				inp->next = inp;
-				inp->prev = inp;
-				_giiUpdateCache(inp);
-				if (_gii_threadsafe) {
-					ggUnlock(inp->mutex);
-				}
-				/* newhand may still be a joined input,
-				 * so we inform the user of that. */
-				return 1;
-			}
-			/* inp!=idx */
-			if (_gii_threadsafe) {
-				ggLock(idx->mutex); /* no check needed as idx!=inp by definition */
-			}
-			_giiEvQueueAllocate(idx);
+	trynextone:
+		idx = idx->next;
+		continue;
+
+	haveit:
+		if (inp == idx) {
+			/* Ooops - we try to split off the _first_ input. This is a special case.
+			 */
+
+			/* Make a new queue for me. Old is 
+			 * retained due to pointers in other inputs. 
+			 */
+			_giiEvQueueAllocate(inp); 
 			inp->safequeue = NULL;
-			if (idx->cache != NULL) {
-				idx->cache->count--;
-				if (idx->cache->count == 0) 
-					_giiCacheFree(idx->cache);
-				idx->cache = _giiCacheAlloc();
-				idx->cache->count++;
+			if (inp->cache != NULL) {
+				inp->cache->count--;
+				if (inp->cache->count == 0) {
+					_giiCacheFree(inp->cache);
+					inp->cache = _giiCacheAlloc();
+				}
+				inp->cache->count++;
 			}
+
+			/* lock adjacent inputs as they will be changed now (relink) */
 			if (_gii_threadsafe) {
-				if (idx->next != inp)
-					ggLock(idx->next->mutex);
-				if (idx->prev != inp)
-					ggLock(idx->prev->mutex);
-				/* the case idx->prev==idx->next cannot happen, 
-				 * because that would have to be inp, then. 
-				 * Otherwise the circular list would be 
-				 * corrupted already anyway.
-				 */
+				ggLock(inp->next->mutex);
+				if (inp->next != inp->prev)
+					ggLock(inp->prev->mutex);
 			}
-			idx->prev->next = idx->next;
-			idx->next->prev = idx->prev;
-			if (_gii_threadsafe) {
-				if (idx->prev != inp)
-					ggUnlock(idx->prev->mutex);
-				if (idx->next != inp)
-					ggUnlock(idx->next->mutex);
-			}
-			idx->next = idx;
-			idx->prev = idx;
-			*newhand = idx;
+			inp->next->prev = inp->prev;
+			inp->prev->next = inp->next;
+			*newhand = inp->next;
 			_giiUpdateCache(*newhand);
+			/* unlock adjacent inputs again. */
+			if (_gii_threadsafe) {
+				if (inp->next != inp->prev)
+					ggUnlock(inp->prev->mutex);
+				ggUnlock(inp->next->mutex);
+				/* Look closely:
+				 * inp->queue has been overwritten during 
+				 * _giiEvQueueAllocate(inp); However 
+				 * inp->queue->mutex ist still locked.
+				 * inp->next->queue has a copy of the old 
+				 * contents of inp->queue, so we use that.
+				 */
+				ggUnlock(inp->next->queue->mutex);
+			}
+			/* selflink myself. */
+			inp->next = inp;
+			inp->prev = inp;
 			_giiUpdateCache(inp);
 			if (_gii_threadsafe) {
-				ggUnlock(idx->mutex);
-				ggUnlock(inp->queue->mutex);
 				ggUnlock(inp->mutex);
 			}
-			return GGI_OK;
-		} /* found origin to split off */
+			/* newhand may still be a joined input,
+			 * so we inform the user of that. */
+			return 1;
+		}
+		/* inp!=idx */
+		if (_gii_threadsafe) {
+			ggLock(idx->mutex); /* no check needed as idx!=inp by definition */
+		}
+		_giiEvQueueAllocate(idx);
+		inp->safequeue = NULL;
+		if (idx->cache != NULL) {
+			idx->cache->count--;
+			if (idx->cache->count == 0) 
+				_giiCacheFree(idx->cache);
+			idx->cache = _giiCacheAlloc();
+			idx->cache->count++;
+		}
+		if (_gii_threadsafe) {
+			if (idx->next != inp)
+				ggLock(idx->next->mutex);
+			if (idx->prev != inp)
+				ggLock(idx->prev->mutex);
+			/* the case idx->prev==idx->next cannot happen, 
+			 * because that would have to be inp, then. 
+			 * Otherwise the circular list would be 
+			 * corrupted already anyway.
+			 */
+		}
+		idx->prev->next = idx->next;
+		idx->next->prev = idx->prev;
+		if (_gii_threadsafe) {
+			if (idx->prev != inp)
+				ggUnlock(idx->prev->mutex);
+			if (idx->next != inp)
+				ggUnlock(idx->next->mutex);
+		}
+		idx->next = idx;
+		idx->prev = idx;
+		*newhand = idx;
+		_giiUpdateCache(*newhand);
+		_giiUpdateCache(inp);
+		if (_gii_threadsafe) {
+			ggUnlock(idx->mutex);
+			ggUnlock(inp->queue->mutex);
+			ggUnlock(inp->mutex);
+		}
+		return GGI_OK;
 
-		idx = idx->next;
 	} while (idx != inp);
 
 	if (_gii_threadsafe) {
@@ -1062,9 +1208,9 @@ int giiEventSend(struct gii_input *inp, gii_event *event)
 
 	LIBGII_APPASSERT(inp != NULL, "giiEventSend: inp is NULL");
 
-	GII_EV_TIMESTAMP(event);
+	_GII_ev_timestamp(event);
 
-	/* FIXME! We should alow this to be or-ed in */
+	/* FIXME! We should allow this to be or-ed in */
 	event->any.origin = GII_EV_ORIGIN_SENDEVENT;
 
 	if (event->any.target == GII_EV_TARGET_QUEUE) {
@@ -1128,7 +1274,7 @@ int giiQueryDeviceInfo(gii_input_t inp, uint32 origin,
 	if (di) {
 		*info=*di->dev;return 0;
 	}
-	return -1;
+	return GGI_ENOMATCH;
 }
 
 static gii_deviceinfo *
@@ -1155,7 +1301,7 @@ int giiQueryDeviceInfoByNumber(gii_input_t inp, uint32 number, uint32 *origin,
 	if (di) {
 		*info=*di->dev;return 0;
 	}
-	return -1;
+	return GGI_ENOMATCH;
 }
 
 int giiQueryValInfo(gii_input_t inp, uint32 origin, uint32 valnumber,
@@ -1163,9 +1309,9 @@ int giiQueryValInfo(gii_input_t inp, uint32 origin, uint32 valnumber,
 {
 	gii_deviceinfo *di=giiFindDeviceInfo(inp,origin);
 	if (di) {
-		if (valnumber>=di->dev->num_axes) return -1;
-		*info=di->val[valnumber];return 0;
+		if (valnumber >= di->dev->num_axes) return GGI_ENOSPACE;
+		*info = di->val[valnumber];return 0;
 	}
-	return -1;
+	return GGI_ENOMATCH;
 }
 
