@@ -1,4 +1,4 @@
-/* $Id: init.c,v 1.3.2.1 2003/11/13 21:43:58 cegger Exp $
+/* $Id: init.c,v 1.8.4.2 2004/11/14 21:58:13 cegger Exp $
 ******************************************************************************
 
    LibGII initialization.
@@ -41,14 +41,15 @@
 
 
 /* Exported variables */
-EXPORTVAR uint32      _giiDebugState	= 0;
-EXPORTVAR int         _giiDebugSync	= 0;
-EXPORTVAR int         _gii_threadsafe	= 0;
-EXPORTVAR void       *_gii_global_lock  = NULL;
+uint32                _giiDebugState   = 0;
+int                   _giiDebugSync    = 0;
+int                   _gii_threadsafe  = 0;
+void                 *_gii_global_lock = NULL;
 
 /* Global variables */
 void                 *_giiconfhandle	= NULL;
 void                 *_gii_safe_lock	= NULL;
+void                 *_gii_event_lock	= NULL;
 
 /* Static variables */
 static int 	      _giiLibIsUp =0 ;
@@ -62,7 +63,7 @@ static char          *giiconfdir = giiconfstub + GIITAGLEN;
 
 const char *giiGetConfDir(void)
 {
-#ifdef __WIN32__
+#if defined(__WIN32__) && !defined(__CYGWIN__)
 	/* On Win32 we allow overriding of the compiled in path. */
 	const char *envdir = getenv("GGI_CONFDIR");
 	if (envdir) return envdir;
@@ -105,9 +106,14 @@ int giiInit(void)
 	}
 
 	err = GGI_ENOMEM;
+	if ((_gii_event_lock = ggLockCreate()) == NULL) {
+		fprintf(stderr,"LibGII: unable to initialize event mutex.\n");
+		goto out_ggexit;
+	}
+
 	if ((_gii_safe_lock = ggLockCreate()) == NULL) {
 		fprintf(stderr,"LibGII: unable to initialize safe mutex.\n");
-		goto out_ggexit;
+		goto out_destroy_event;
 	}
 
 	if ((_gii_global_lock = ggLockCreate()) == NULL) {
@@ -121,8 +127,13 @@ int giiInit(void)
 		fprintf(stderr,"LibGII: unable to allocate memory for config filename.\n");
 		goto out_destroy_global;
 	}
+#ifdef HAVE_SNPRINTF
+	snprintf(conffile, strlen(giiGetConfDir()) + strlen(GIICONFFILE) + 2,
+		"%s%c%s", giiGetConfDir(), CHAR_DIRDELIM, GIICONFFILE);
+#else
 	sprintf(conffile, "%s%c%s",
 		giiGetConfDir(), CHAR_DIRDELIM,	GIICONFFILE);
+#endif
 	err = ggLoadConfig(conffile, &_giiconfhandle);
 	if (err != GGI_OK) {
 		fprintf(stderr, "LibGII: fatal error - could not load %s\n",
@@ -132,17 +143,19 @@ int giiInit(void)
 	}
 	free(conffile);
 
-	str = getenv("GGI_DEBUG");
-	if (str != NULL) {
-		_giiDebugState = atoi(str);
-		GIIDPRINT_CORE("Debugging=%d\n", _giiDebugState);
-	}
-
 	str = getenv("GGI_DEBUGSYNC");
 	if (str != NULL) {
 		_giiDebugSync = 1;
 	}
 
+	str = getenv("GGI_DEBUG");
+	if (str != NULL) {
+		_giiDebugState = atoi(str);
+		GIIDPRINT_CORE("%s Debugging=%d\n",
+				_giiDebugSync ? "sync" : "async",
+				_giiDebugState);
+	}
+
 	_giiLibIsUp++;
 
 	return 0;
@@ -151,6 +164,8 @@ int giiInit(void)
 	ggLockDestroy(_gii_global_lock);
   out_destroy_safe:
 	ggLockDestroy(_gii_safe_lock);
+  out_destroy_event:
+	ggLockDestroy(_gii_event_lock);
   out_ggexit:
 	ggExit();
 
@@ -161,7 +176,7 @@ int giiExit(void)
 {
 	GIIDPRINT_CORE("giiExit() called\n");
 	if (!_giiLibIsUp)
-		return -1;
+		return GGI_ENOTALLOC;
 
 	if (_giiLibIsUp > 1) {
 		_giiLibIsUp--;
@@ -173,6 +188,7 @@ int giiExit(void)
 	ggFreeConfig(_giiconfhandle);
 	ggLockDestroy(_gii_global_lock);
 	ggLockDestroy(_gii_safe_lock);
+	ggLockDestroy(_gii_event_lock);
 	ggExit();
 	_giiLibIsUp=0;
 
