@@ -1,4 +1,4 @@
-/* $Id: errors.h,v 1.1.1.1 2001/05/12 23:00:10 cegger Exp $
+/* $Id: errors.h,v 1.1.1.1.6.1 2004/11/14 12:56:31 cegger Exp $
 ******************************************************************************
 
    GGI error definitions
@@ -51,7 +51,7 @@
 #define GGI_EFATAL	-26	/* Fatal error - the state of the target of
 				   the operation is undefined */
 #define GGI_EBADFILE	-27	/* Error reading (config) file */
-#define GGI_ENOSPACE	-28	/* Out of space */
+#define GGI_ENOSPACE	-28	/* Out of space / range */
 #define GGI_ENOFUNC	-29	/* Function not implemented */
 #define GGI_EBUSY	-30	/* Object is busy */
 #define GGI_ENOTFOUND	-31	/* The requested object was not found */
@@ -59,7 +59,8 @@
 				   which only supports exclusive access */
 #define GGI_ENOMATCH	-33	/* No matching entry found */
 
-#define GGI_EEVUNKNOWN	-40	/* Unknown event sent to input source */
+#define GGI_EEVUNKNOWN	-40	/* Unknown event sent to or received from
+				   input source */
 #define GGI_EEVNOTARGET	-41	/* No apropriate target for sent event */
 #define GGI_EEVOVERFLOW	-42	/* Overflow when queuing event */
 
