@@ -1,4 +1,4 @@
-/* $Id: keyboard.h,v 1.13 1999/03/11 17:36:01 marcus Exp $
+/* $Id$
 ******************************************************************************
 
    LibGII keyboard definitions
@@ -42,6 +42,7 @@
 #define GII_KT_PAD	0xE2
 #define GII_KT_MOD	0xE3
 #define GII_KT_DEAD	0xE4
+#define GII_KT_RC	0xE5
 
 /* modifiers */
 
@@ -145,8 +146,11 @@
 
 #define GIIK_VOID		GII_KEY(GII_KT_SPEC, 0)
 
-#define GIIK_Enter		GIIUC_Return
-#define GIIK_Delete		GIIUC_Delete
+/* GIIK_Enter and GIIK_Delete are equal to GIIUC_Return
+ * and GIIUC_Delete, but they get #defined far below
+ * from here. Thus use the hardcoded ASCII values. */
+#define GIIK_Enter		0x0d
+#define GIIK_Delete		0x7f
 
 #define GIIK_Break		GII_KEY(GII_KT_SPEC, 5)
 
@@ -233,6 +237,176 @@
 #define GIIK_PF8		GII_KEY(GII_KT_PAD, 0x98)
 #define GIIK_PF9		GII_KEY(GII_KT_PAD, 0x99)
 
+/* Remote control, shortcut, and digi keys.  Note: corresponds to linux's 
+ * linux-input, which is likely to be the dominant system eventually,
+ * given most people are too lazy to make their own keymaps and lirc doesn't
+ * have a base keymap, just some key symbol names.
+ *
+ * So, try to keep a simple mapping to linux-input if possible when 
+ * adding keys.
+ * 
+ * Current mapping against linux/input.h:
+ * "keys" 0x140-0x19f are mapped to GII_KT_RC | (0x10 to 0x6f)
+ * "keys" 0x70 and up are mapped to their code | GII_KT_RC, except
+ * for those which existed prior to adding the linux-input keys.
+ *
+ * Note that while the GII_KT_RC codes may appear in mainstream
+ * sources they are not considered to be formally part of this
+ * version of LibGII; they will become formally valid in the next 
+ * release of LibGII (when this comment will hopefully be deleted :-)
+ *
+ */
+
+#define GIIK_Digi		GII_KEY(GII_KT_RC,(0x140 - 0x130))
+#define GIIK_Tool_Pen		GII_KEY(GII_KT_RC,(0x140 - 0x130))
+#define GIIK_Tool_Rubber	GII_KEY(GII_KT_RC,(0x141 - 0x130))
+#define GIIK_Tool_Brush		GII_KEY(GII_KT_RC,(0x142 - 0x130))
+#define GIIK_Tool_Pencil	GII_KEY(GII_KT_RC,(0x143 - 0x130))
+#define GIIK_Tool_Airbrush	GII_KEY(GII_KT_RC,(0x144 - 0x130))
+#define GIIK_Tool_Finger	GII_KEY(GII_KT_RC,(0x145 - 0x130))
+#define GIIK_Tool_Mouse		GII_KEY(GII_KT_RC,(0x146 - 0x130))
+#define GIIK_Tool_Lens		GII_KEY(GII_KT_RC,(0x147 - 0x130))
+#define GIIK_Touch		GII_KEY(GII_KT_RC,(0x14a - 0x130))
+#define GIIK_Stylus		GII_KEY(GII_KT_RC,(0x14b - 0x130))
+#define GIIK_Stylus2		GII_KEY(GII_KT_RC,(0x14c - 0x130))
+#define GIIK_Tool_DoubleTap	GII_KEY(GII_KT_RC,(0x14d - 0x130))
+#define GIIK_Tool_TripleTap	GII_KEY(GII_KT_RC,(0x14e - 0x130))
+#define GIIK_Ok			GII_KEY(GII_KT_RC,(0x160 - 0x130))
+#define GIIK_Goto		GII_KEY(GII_KT_RC,(0x162 - 0x130))
+#define GIIK_Power2		GII_KEY(GII_KT_RC,(0x164 - 0x130))
+#define GIIK_Option		GII_KEY(GII_KT_RC,(0x165 - 0x130))
+#define GIIK_Info		GII_KEY(GII_KT_RC,(0x166 - 0x130))
+#define GIIK_Time		GII_KEY(GII_KT_RC,(0x167 - 0x130))
+#define GIIK_Vendor		GII_KEY(GII_KT_RC,(0x168 - 0x130))
+#define GIIK_Archive		GII_KEY(GII_KT_RC,(0x169 - 0x130))
+#define GIIK_Program		GII_KEY(GII_KT_RC,(0x16a - 0x130))
+#define GIIK_Channel		GII_KEY(GII_KT_RC,(0x16b - 0x130))
+#define GIIK_Favorites		GII_KEY(GII_KT_RC,(0x16c - 0x130))
+#define GIIK_Epg		GII_KEY(GII_KT_RC,(0x16d - 0x130))
+#define GIIK_Pvr		GII_KEY(GII_KT_RC,(0x16e - 0x130))
+#define GIIK_Mhp		GII_KEY(GII_KT_RC,(0x16f - 0x130))
+#define GIIK_Language		GII_KEY(GII_KT_RC,(0x170 - 0x130))
+#define GIIK_Title		GII_KEY(GII_KT_RC,(0x171 - 0x130))
+#define GIIK_Subtitle		GII_KEY(GII_KT_RC,(0x172 - 0x130))
+#define GIIK_Angle		GII_KEY(GII_KT_RC,(0x173 - 0x130))
+#define GIIK_Zoom		GII_KEY(GII_KT_RC,(0x174 - 0x130))
+#define GIIK_Mode		GII_KEY(GII_KT_RC,(0x175 - 0x130))
+#define GIIK_Keyboard		GII_KEY(GII_KT_RC,(0x176 - 0x130))
+#define GIIK_Screen		GII_KEY(GII_KT_RC,(0x177 - 0x130))
+#define GIIK_Vga		GII_KEY(GII_KT_RC,(0x178 - 0x130))
+#define GIIK_Tv			GII_KEY(GII_KT_RC,(0x179 - 0x130))
+#define GIIK_Tv2		GII_KEY(GII_KT_RC,(0x17a - 0x130))
+#define GIIK_Vcr		GII_KEY(GII_KT_RC,(0x17b - 0x130))
+#define GIIK_Vcr2		GII_KEY(GII_KT_RC,(0x17c - 0x130))
+#define GIIK_Sat		GII_KEY(GII_KT_RC,(0x17d - 0x130))
+#define GIIK_Sat2		GII_KEY(GII_KT_RC,(0x17e - 0x130))
+#define GIIK_Cd			GII_KEY(GII_KT_RC,(0x17f - 0x130))
+#define GIIK_Tape		GII_KEY(GII_KT_RC,(0x180 - 0x130))
+#define GIIK_Radio		GII_KEY(GII_KT_RC,(0x181 - 0x130))
+#define GIIK_Tuner		GII_KEY(GII_KT_RC,(0x182 - 0x130))
+#define GIIK_Player		GII_KEY(GII_KT_RC,(0x183 - 0x130))
+#define GIIK_Text		GII_KEY(GII_KT_RC,(0x184 - 0x130))
+#define GIIK_Dvd		GII_KEY(GII_KT_RC,(0x185 - 0x130))
+#define GIIK_Aux		GII_KEY(GII_KT_RC,(0x186 - 0x130))
+#define GIIK_Mp3		GII_KEY(GII_KT_RC,(0x187 - 0x130))
+#define GIIK_Audio		GII_KEY(GII_KT_RC,(0x188 - 0x130))
+#define GIIK_Video		GII_KEY(GII_KT_RC,(0x189 - 0x130))
+#define GIIK_Directory		GII_KEY(GII_KT_RC,(0x18a - 0x130))
+#define GIIK_List		GII_KEY(GII_KT_RC,(0x18b - 0x130))
+#define GIIK_Memo		GII_KEY(GII_KT_RC,(0x18c - 0x130))
+#define GIIK_Calendar		GII_KEY(GII_KT_RC,(0x18d - 0x130))
+#define GIIK_Red		GII_KEY(GII_KT_RC,(0x18e - 0x130))
+#define GIIK_Green		GII_KEY(GII_KT_RC,(0x18f - 0x130))
+#define GIIK_Yellow		GII_KEY(GII_KT_RC,(0x190 - 0x130))
+#define GIIK_Blue		GII_KEY(GII_KT_RC,(0x191 - 0x130))
+#define GIIK_ChannelUp		GII_KEY(GII_KT_RC,(0x192 - 0x130))
+#define GIIK_ChannelDown	GII_KEY(GII_KT_RC,(0x193 - 0x130))
+#define GIIK_First		GII_KEY(GII_KT_RC,(0x194 - 0x130))
+#define GIIK_Last		GII_KEY(GII_KT_RC,(0x195 - 0x130))
+#define GIIK_Ab			GII_KEY(GII_KT_RC,(0x196 - 0x130))
+#define GIIK_Restart		GII_KEY(GII_KT_RC,(0x198 - 0x130))
+#define GIIK_Slow		GII_KEY(GII_KT_RC,(0x199 - 0x130))
+#define GIIK_Shuffle		GII_KEY(GII_KT_RC,(0x19a - 0x130))
+#define GIIK_Previous		GII_KEY(GII_KT_RC,(0x19c - 0x130))
+#define GIIK_Digits		GII_KEY(GII_KT_RC,(0x19d - 0x130))
+#define GIIK_Teen		GII_KEY(GII_KT_RC,(0x19e - 0x130))
+#define GIIK_Twen		GII_KEY(GII_KT_RC,(0x19f - 0x130))
+#define GIIK_Mute		GII_KEY(GII_KT_RC,113)
+#define GIIK_VolumeDown		GII_KEY(GII_KT_RC,114)
+#define GIIK_VolumeUp		GII_KEY(GII_KT_RC,115)
+#define GIIK_Power		GII_KEY(GII_KT_RC,116)
+#define GIIK_Again		GII_KEY(GII_KT_RC,129)
+#define GIIK_Props		GII_KEY(GII_KT_RC,130)
+#define GIIK_Front		GII_KEY(GII_KT_RC,132)
+#define GIIK_Copy		GII_KEY(GII_KT_RC,133)
+#define GIIK_Open		GII_KEY(GII_KT_RC,134)
+#define GIIK_Paste		GII_KEY(GII_KT_RC,135)
+#define GIIK_Cut		GII_KEY(GII_KT_RC,137)
+#define GIIK_Calc		GII_KEY(GII_KT_RC,140)
+#define GIIK_Setup		GII_KEY(GII_KT_RC,141)
+#define GIIK_Sleep		GII_KEY(GII_KT_RC,142)
+#define GIIK_Wakeup		GII_KEY(GII_KT_RC,143)
+#define GIIK_File		GII_KEY(GII_KT_RC,144)
+#define GIIK_SendFile		GII_KEY(GII_KT_RC,145)
+#define GIIK_DeleteFile		GII_KEY(GII_KT_RC,146)
+#define GIIK_Xfer		GII_KEY(GII_KT_RC,147)
+#define GIIK_Prog1		GII_KEY(GII_KT_RC,148)
+#define GIIK_Prog2		GII_KEY(GII_KT_RC,149)
+#define GIIK_Www		GII_KEY(GII_KT_RC,150)
+#define GIIK_Msdos		GII_KEY(GII_KT_RC,151)
+#define GIIK_Coffee		GII_KEY(GII_KT_RC,152)
+#define GIIK_Direction		GII_KEY(GII_KT_RC,153)
+#define GIIK_CycleWindows	GII_KEY(GII_KT_RC,154)
+#define GIIK_Mail		GII_KEY(GII_KT_RC,155)
+#define GIIK_Bookmarks		GII_KEY(GII_KT_RC,156)
+#define GIIK_Computer		GII_KEY(GII_KT_RC,157)
+#define GIIK_Back		GII_KEY(GII_KT_RC,158)
+#define GIIK_Forward		GII_KEY(GII_KT_RC,159)
+#define GIIK_CloseCd		GII_KEY(GII_KT_RC,160)
+#define GIIK_EjectCd		GII_KEY(GII_KT_RC,161)
+#define GIIK_EjectCloseCd	GII_KEY(GII_KT_RC,162)
+#define GIIK_NextSong		GII_KEY(GII_KT_RC,163)
+#define GIIK_PlayPause		GII_KEY(GII_KT_RC,164)
+#define GIIK_PreviousSong	GII_KEY(GII_KT_RC,165)
+#define GIIK_StopCd		GII_KEY(GII_KT_RC,166)
+#define GIIK_Record		GII_KEY(GII_KT_RC,167)
+#define GIIK_Rewind		GII_KEY(GII_KT_RC,168)
+#define GIIK_Phone		GII_KEY(GII_KT_RC,169)
+#define GIIK_Iso		GII_KEY(GII_KT_RC,170)
+#define GIIK_Config		GII_KEY(GII_KT_RC,171)
+#define GIIK_Homepage		GII_KEY(GII_KT_RC,172)
+#define GIIK_Refresh		GII_KEY(GII_KT_RC,173)
+#define GIIK_Exit		GII_KEY(GII_KT_RC,174)
+#define GIIK_Move		GII_KEY(GII_KT_RC,175)
+#define GIIK_Edit		GII_KEY(GII_KT_RC,176)
+#define GIIK_ScrollUp		GII_KEY(GII_KT_RC,177)
+#define GIIK_ScrollDown		GII_KEY(GII_KT_RC,178)
+#define GIIK_PlayCd		GII_KEY(GII_KT_RC,200)
+#define GIIK_PauseCd		GII_KEY(GII_KT_RC,201)
+#define GIIK_Prog3		GII_KEY(GII_KT_RC,202)
+#define GIIK_Prog4		GII_KEY(GII_KT_RC,203)
+#define GIIK_Suspend		GII_KEY(GII_KT_RC,205)
+#define GIIK_Close		GII_KEY(GII_KT_RC,206)
+#define GIIK_Play		GII_KEY(GII_KT_RC,207)
+#define GIIK_FastForward	GII_KEY(GII_KT_RC,208)
+#define GIIK_BassBoost		GII_KEY(GII_KT_RC,209)
+#define GIIK_Print		GII_KEY(GII_KT_RC,210)
+#define GIIK_Hp			GII_KEY(GII_KT_RC,211)
+#define GIIK_Camera		GII_KEY(GII_KT_RC,212)
+#define GIIK_Sound		GII_KEY(GII_KT_RC,213)
+#define GIIK_Question		GII_KEY(GII_KT_RC,214)
+#define GIIK_Email		GII_KEY(GII_KT_RC,215)
+#define GIIK_Chat		GII_KEY(GII_KT_RC,216)
+#define GIIK_Search		GII_KEY(GII_KT_RC,217)
+#define GIIK_Connect		GII_KEY(GII_KT_RC,218)
+#define GIIK_Finance		GII_KEY(GII_KT_RC,219)
+#define GIIK_Sport		GII_KEY(GII_KT_RC,220)
+#define GIIK_Shop		GII_KEY(GII_KT_RC,221)
+#define GIIK_Alterase		GII_KEY(GII_KT_RC,222)
+#define GIIK_BrightnessDown	GII_KEY(GII_KT_RC,224)
+#define GIIK_BrightnessUp	GII_KEY(GII_KT_RC,225)
+#define GIIK_Media		GII_KEY(GII_KT_RC,226)
+
 /* modifier keys */
 
 #define GIIK_Shift		GII_KEY(GII_KT_MOD, GII_KM_SHIFT)
