@@ -1,4 +1,4 @@
-/* $Id: eventparse.c,v 1.2.2.3 2004/03/28 20:14:42 cegger Exp $
+/* $Id: eventparse.c,v 1.6 2004/03/28 18:36:10 skids Exp $
 ******************************************************************************
 
    Linux evdev parser
@@ -129,7 +129,13 @@ dispatch_key(struct gii_input *inp, struct input_event *event, gii_event *ev)
 	ev->key.button = event->code;
 	if (event->code < 0x100) {
 		/* Keyboard key. */
+
+		/* Attention: gcc bug:
+		 * passing arg 2 of `GII_levdev_key2label' with different 
+		 * width due to prototype
+		 */
 		ev->key.label = GII_levdev_key2label(inp, event->code);
+
 		ev->key.sym = ev->key.label;
 	} else {
 		/* Other button. */
@@ -172,12 +178,14 @@ dispatch_abs(struct gii_input *inp, struct input_event *event, gii_event *ev)
 }
 
 
+typedef gii_event_mask (func_dispatcher)(struct gii_input *inp,
+				    struct input_event *event,
+				    gii_event *ev);
+
 static gii_event_mask
 dispatch_event(struct gii_input *inp, struct input_event *event)
 {
-	gii_event_mask (*dispatcher)(struct gii_input *inp,
-				    struct input_event *event,
-				    gii_event *ev);
+	func_dispatcher	*dispatcher;
 	gii_event ev;
 	int ret;
 
