@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.5 2002/02/22 21:51:05 soyt Exp $
+/* $Id: input.c,v 1.11.4.1 2004/11/14 13:07:17 cegger Exp $
 ******************************************************************************
 
    Mouse: input
@@ -28,10 +28,16 @@
 #include "config.h"
 #include <ggi/internal/gii-dl.h>
 #include <ggi/internal/gii_debug.h>
+#include <ggi/internal/gii_target.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+
 #include <ctype.h>
 #include <errno.h>
 
@@ -130,7 +136,7 @@ static int find_mouse(char *name)
 	}
 	fprintf(stderr, "Unknown mouse type '%s'\n", name);
 
-	return -1;
+	return GGI_ENOTFOUND;
 }
 
 #if 0
@@ -308,7 +314,7 @@ static void libvga_to_options(char *str, char *options)
 	/* Put a terminator after the protocol name */
 	*str = '\0';
 	str++;
-	
+
 	/* handle the libvga options */
 	while (sscanf(str, " %s%n", buf, &len) == 1) {
 		
@@ -364,7 +370,7 @@ static char *get_value_from_XF86Config(char *str)
 }
 
 static int get_from_XF86Config(const char *filename,
-				char *devname,char *protname, char *options)
+				char *_devname,char *protname, char *options)
 {
 	FILE *file;
 	char line[MAX_LINELEN];
@@ -393,7 +399,7 @@ static int get_from_XF86Config(const char *filename,
 				GotKonfig=1;
 			} else if (0==strncasecmp(lineptr,"Device",6)) {
 				lineptr+=6;
-				strncpy(devname,get_value_from_XF86Config(lineptr),MAX_OPTLEN);
+				strncpy(_devname,get_value_from_XF86Config(lineptr),MAX_OPTLEN);
 			} else if (0==strncasecmp(lineptr,"BaudRate",8)) {
 				lineptr+=6;
 				strcat(options, "b");
@@ -420,21 +426,21 @@ static int get_from_XF86Config(const char *filename,
 
 
 static void parse_mouse_specifier(char *spec, char *protname,
-				  char *devname, char *options)
+				  char *_devname, char *options)
 {
-	*protname = *devname = *options = '\0';
+	*protname = *_devname = *options = '\0';
 
 	/* LISP-haters should shut their eyes now :) */
 	if (spec) {
 		parse_field(options, MAX_OPTLEN,
-			    parse_field(devname, MAX_OPTLEN,
+			    parse_field(_devname, MAX_OPTLEN,
 					parse_field(protname, MAX_OPTLEN,
 						    spec)));
 	}
 
 	/* supply defaults for missing bits */
-	if (*devname == '\0') {
-		strcpy(devname, "/dev/mouse");
+	if (*_devname == '\0') {
+		strcpy(_devname, "/dev/mouse");
 	}
 
 	if (*protname == '\0' || strcmp(protname, "auto") == 0) {
@@ -453,7 +459,7 @@ static void parse_mouse_specifier(char *spec, char *protname,
 			dirname = ggGetUserDir();
 			if (strlen(dirname) + sizeof(appendstr) < 2048) {
 				sprintf(fname, "%s%s", dirname, appendstr);
-				if (get_from_file(fname, protname, devname)
+				if (get_from_file(fname, protname, _devname)
 				    == 0) {
 					return;
 				}
@@ -462,14 +468,14 @@ static void parse_mouse_specifier(char *spec, char *protname,
 			dirname = giiGetConfDir();
 			if (strlen(dirname) + sizeof(appendstr) < 2048) {
 				sprintf(fname, "%s%s", dirname, appendstr);
-				if (get_from_file(fname, protname, devname)
+				if (get_from_file(fname, protname, _devname)
 				    == 0) {
 					return;
 				}
 			}
 		} while (0);
 
-		if (strncmp(devname, "/dev/gpm", 8) == 0) {
+		if (strncmp(_devname, "/dev/gpm", 8) == 0) {
 			strcpy(protname, "msc");
 			return;
 		}
@@ -477,7 +483,7 @@ static void parse_mouse_specifier(char *spec, char *protname,
 		do {
 			struct stat m_stat;
 
-			if ((stat(devname, &m_stat) == 0) &&
+			if ((stat(_devname, &m_stat) == 0) &&
 			    S_ISCHR(m_stat.st_mode) &&
 			    (MAJOR(m_stat.st_rdev) == MISC_MAJOR)) {
 				switch (MINOR(m_stat.st_rdev)) {
@@ -496,7 +502,7 @@ static void parse_mouse_specifier(char *spec, char *protname,
 			char buf[1024];
 			int len;
 			
-			len = readlink(devname, buf, 1024);
+			len = readlink(_devname, buf, 1024);
 			if (len > 0 && len < 1024) {
 				buf[len] = '\0';
 				if (strstr(buf, "gpm") != NULL) {
@@ -509,13 +515,13 @@ static void parse_mouse_specifier(char *spec, char *protname,
 
 		/* Try to parse XF86Config */
 		if (get_from_XF86Config("/etc/X11/XF86Config",
-					devname,protname,options)==0) return;
+					_devname,protname,options)==0) return;
 		if (get_from_XF86Config("/etc/XF86Config",
-					devname,protname,options)==0) return;
+					_devname,protname,options)==0) return;
 		
 		/* Try to parse SVGAlib config file as a last resort */
 		if (get_from_file("/etc/vga/libvga.config",
-				  protname, devname) == 0) {
+				  protname, _devname) == 0) {
 			if (strlen(options) == 0) {
 				libvga_to_options(protname, options);
 			}
@@ -583,11 +589,12 @@ static int GII_mouse_close(gii_input *inp)
 	return 0;
 }
 
+
 int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 {
 	l_mouse_priv *mhook;
 	char protname[MAX_OPTLEN+1];
-	char devname[MAX_OPTLEN+1];
+	char _devname[MAX_OPTLEN+1];
 	char options[MAX_OPTLEN+1];
 	char argstring[MAX_OPTLEN+1+128];
 	int mindex, ret;
@@ -604,10 +611,10 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	}
 
 	/* parse the mouse specifier */
-	parse_mouse_specifier(spec, protname, devname, options);
+	parse_mouse_specifier(spec, protname, _devname, options);
 	parse_options(options, &baud, &dtr, &rts);
 	GIIDPRINT_MISC("linux_mouse: prot=`%s' dev=`%s' opts=`%s'\n",
-		    protname, devname, options);
+		    protname, _devname, options);
 
 	if (*protname == '\0' || (mindex = find_mouse(protname)) < 0) {
 		return GGI_EARGINVAL;
@@ -622,7 +629,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
  	/* Open mouse */
 	mhook->type = mice_types + mindex;
 
-	if ((ret = do_mouse_open(inp, devname, dtr, rts, baud)) < 0) {
+	if ((ret = do_mouse_open(inp, _devname, dtr, rts, baud)) < 0) {
 		free(mhook);
 		return ret;
 	}
