@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.3.2.2 2003/02/01 14:33:32 cegger Exp $
+/* $Id: input.c,v 1.10 2004/09/16 13:24:59 pekberg Exp $
 ******************************************************************************
 
    Mouse inputlib init function
@@ -26,11 +26,17 @@
 */
 #include "config.h"
 #include "mouse.h"
+#include <ggi/internal/gii_target.h>
+
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 #include <unistd.h>
 
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+
 #define SKIPWHITE(str)	while (isspace((int)*(str))) (str)++
 
 static gii_cmddata_getdevinfo devinfo =
@@ -46,7 +52,9 @@ static void send_devinfo(gii_input *inp)
 {
 	gii_event ev;
 	gii_cmddata_getdevinfo *dinfo;
-	int size = sizeof(gii_cmd_nodata_event)+sizeof(gii_cmddata_getdevinfo);
+	size_t size;
+
+	size = sizeof(gii_cmd_nodata_event)+sizeof(gii_cmddata_getdevinfo);
 
 	_giiEventBlank(&ev, size);
 	
@@ -110,18 +118,20 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	int fd, fallback_parser = 0;
 	
 	if (! (args && *args
-	       && (fd = strtol(args, &mtype, 0)) >= 0 && mtype != args
-	       /* FIXME - we should allow PnP for the mousetype */
-	       && *mtype != '\0')) {
+	  && (fd = strtol(args, &mtype, 0)) >= 0 && mtype != args
+	  /* FIXME - we should allow PnP for the mousetype */
+	  && *mtype != '\0'))
+	{
 		return GGI_EARGREQ;
 	}
-	
+
 	if ((parser = match_mtype(mtype)) == NULL) {
 		return GGI_EARGINVAL;
 	}
 	if (parser->init_data) {
-		if (write(fd, parser->init_data, parser->init_len)
-		    != parser->init_len) {
+		if (write(fd, parser->init_data, (unsigned)parser->init_len)
+		    != parser->init_len)
+		{
 			switch(parser->init_type) {
 			case GII_MIT_DONTCARE:
 				break;
@@ -153,7 +163,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	inp->curreventmask = emPointer | emCommand;
 
 	inp->maxfd = fd + 1;
-	FD_SET(fd, &inp->fdset);
+	FD_SET((unsigned)(fd), &inp->fdset);
 
 	if (fallback_parser) {
 		mpriv->parser = parser->fbparser->parser;
