@@ -1,4 +1,4 @@
-/* $Id: packetparse.c,v 1.2.2.1 2003/04/14 20:54:28 cegger Exp $
+/* $Id: packetparse.c,v 1.4 2003/07/04 22:38:29 cegger Exp $
 ******************************************************************************
 
    Mouse packet parsing
@@ -140,12 +140,12 @@ static int parse_ms(gii_input *inp, uint8 *buf, int len)
 	
 	/* Should allow motion _and_ button change */
 	if ((dx == 0) && (dy == 0)
-	    && (buttons == (mpriv->button_state & ~4))) {
+	    && (buttons == (mpriv->button_state & ~(4U)))) {
 		/* No move or change: toggle middle */
-		buttons = mpriv->button_state ^ 4;
+		buttons = mpriv->button_state ^ 4U;
 	} else {
 		/* Change: preserve middle */
-		buttons |= mpriv->button_state & 4;
+		buttons |= mpriv->button_state & 4U;
 	}
 
 	mouse_send_movement(inp, dx, dy, 0, 0);
@@ -185,7 +185,7 @@ static int parse_ms3(gii_input *inp, uint8 *buf, int len)
 		
 		buttons = ((buf[0] & 0x10) >> 3)
 			| ((buf[0] & 0x20) >> 5)
-			| (mpriv->button_state & ~0x03);
+			| (mpriv->button_state & ~(0x03U));
 		
 		mouse_send_movement(inp, dx, dy, 0, 0);
 		if (buttons != mpriv->button_state) {
@@ -481,7 +481,7 @@ static int parse_mmanps2(gii_input *inp, uint8 *buf, int len)
 			return 1;
 		}
 		buttons = (buf[0] & 0x07)
-			| (mpriv->button_state & ~0x07); /* Fourth button */
+			| (mpriv->button_state & ~(0x07U)); /* Fourth button */
 		dx = (buf[0] & 0x10) ? buf[1] - 256 : buf[1];
 		dy = (buf[0] & 0x20) ? -(buf[2] - 256) : -buf[2];
 	}
@@ -697,7 +697,7 @@ gii_event_mask GII_mouse_poll(gii_input *inp, void *arg)
 
 	/* ASSERT(read_len >= 1) */
 	read_len = read(mpriv->fd, mpriv->packet_buf + mpriv->packet_len, 
-			read_len);
+			(unsigned)read_len);
 
 	if (read_len <= 0) {
 		if (read_len == 0) {
@@ -729,7 +729,7 @@ gii_event_mask GII_mouse_poll(gii_input *inp, void *arg)
 
 		if (mpriv->packet_len > 0) {
 			memmove(mpriv->packet_buf, mpriv->packet_buf + used,
-				mpriv->packet_len);
+				(unsigned)mpriv->packet_len);
 		} else {
 			mpriv->packet_len = 0;
 		}
