@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.5 2002/07/29 17:28:51 cegger Exp $
+/* $Id: input.c,v 1.8.4.1 2004/11/14 13:10:16 cegger Exp $
 ******************************************************************************
 
    Input-pcjoy: all-in-one-file.
@@ -33,6 +33,7 @@
 #include "config.h"
 #include <ggi/internal/gii-dl.h>
 #include <ggi/internal/gii_debug.h>
+#include <ggi/internal/gii_target.h>
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -156,6 +157,7 @@ static int GII_pcjoy_close(gii_input *inp)
 	return 0;
 }
 
+
 int GIIdlinit(gii_input *inp,const char *args, void *argptr)
 {
 	struct joyinfo *joy;
@@ -165,7 +167,7 @@ int GIIdlinit(gii_input *inp,const char *args, void *argptr)
 	if (NULL==(inp->priv=joy=malloc(sizeof(struct joyinfo))))
 	{
 		GIIDPRINT_MISC("input-pcjoy: no memory.\n");
-		return -1;
+		return GGI_ENOMEM;
 	}
 
 	if (ioperm(0x201,1,1))
