@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.4.2.3 2003/11/13 22:01:58 cegger Exp $
+/* $Id: input.c,v 1.11.4.1 2004/11/14 13:07:17 cegger Exp $
 ******************************************************************************
 
    SpaceOrb: input
@@ -36,6 +36,7 @@
 #include "config.h"
 #include <ggi/internal/gii.h>
 #include <ggi/internal/gii_debug.h>
+#include <ggi/internal/gii_target.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -428,18 +429,18 @@ static char *parse_field(char *dst, int max, char *src)
 }
 
 static inline void
-parse_spaceorb_specifier(char *spec, char *devname, char *options)
+parse_spaceorb_specifier(char *spec, char *_devname, char *options)
 {
-	*devname = *options = 0;
+	*_devname = *options = 0;
 
 	if (spec) {
 		parse_field(options, 255,
-			    parse_field(devname, 255, spec));
+			    parse_field(_devname, 255, spec));
 	}
 	
 	/* supply defaults for missing bits */
-	if (*devname == 0) {
-		strcpy(devname, "/dev/spaceorb");
+	if (*_devname == 0) {
+		strcpy(_devname, "/dev/spaceorb");
 	}
 }
 
@@ -485,7 +486,7 @@ static inline int
 GII_spaceorb_init(gii_input *inp, char *typname)
 {
 	SpaceOrbHook *orb = SPACEORB_HOOK(inp);
-	char devname[256];
+	char _devname[256];
 	char options[256];
 	int dtr=-1, rts=-1, baud=-1;
 	int ret;
@@ -498,16 +499,16 @@ GII_spaceorb_init(gii_input *inp, char *typname)
 
 	/* parse the spaceorb specifier */
 	
-	parse_spaceorb_specifier(typname, devname, options);
+	parse_spaceorb_specifier(typname, _devname, options);
 	parse_options(options, &baud, &dtr, &rts);
 
-	if (strcmp(devname, "none") == 0) {
+	if (strcmp(_devname, "none") == 0) {
 		return GGI_ENODEVICE;
 	}
 
  	/* open spaceorb */
 	
-	if ((ret = do_spaceorb_open(inp, devname, dtr, rts, baud)) < 0) {
+	if ((ret = do_spaceorb_open(inp, _devname, dtr, rts, baud)) < 0) {
 		free(orb);
 	}
 	return ret;
@@ -535,7 +536,7 @@ static inline gii_event_mask
 GII_spaceorb_handle_data(gii_input *inp)
 {
 	SpaceOrbHook *orb = SPACEORB_HOOK(inp);
-	int buflen;
+	size_t buflen;
 	int read_len;
 
 	/* read the spaceorb data */
@@ -565,13 +566,13 @@ GII_spaceorb_handle_data(gii_input *inp)
 
 		if (orb->packet_len > 0) {
 			memmove(orb->packet_buf, orb->packet_buf + used,
-				orb->packet_len);
+				(unsigned)orb->packet_len);
 		} else {
 			orb->packet_len = 0;
 		}
 	}
 	
-	if (buflen == read_len) {
+	if (buflen == (size_t)read_len) {
 		/* Filled the buffer - see if there's more data */
 		return 1;
 	} else {
@@ -699,13 +700,13 @@ static int GII_spaceorb_senddevinfo(gii_input *inp)
 	return _giiEvQueueAdd(inp, &ev);
 }
 
-static int GII_spaceorb_sendvalinfo(gii_input *inp, int val)
+static int GII_spaceorb_sendvalinfo(gii_input *inp, uint32 val)
 {
 	gii_cmddata_getvalinfo *VI;
 
 	gii_event ev;
 
-	if (val > 5) return -1;
+	if (val > 5) return GGI_ENOSPACE;
 
 	_giiEventBlank(&ev, sizeof(gii_cmd_nodata_event) +
 		       sizeof(gii_cmddata_getvalinfo));
@@ -728,11 +729,11 @@ static int GII_spaceorb_sendevent(gii_input *inp, gii_event *ev)
 	if ((ev->any.target != inp->origin) &&
 	    (ev->any.target != GII_EV_TARGET_ALL)) {
 		/* not for us */
-		return -1;
+		return GGI_EEVNOTARGET;
 	}
 
 	if (ev->any.type != evCommand) {
-		return -1;
+		return GGI_EEVUNKNOWN;
 	}
 
 	if (ev->cmd.code == GII_CMDCODE_GETDEVINFO) {
@@ -741,7 +742,7 @@ static int GII_spaceorb_sendevent(gii_input *inp, gii_event *ev)
 
 	if (ev->cmd.code == GII_CMDCODE_GETVALINFO) {
 	
-		int i;
+		uint32 i;
 		gii_cmddata_getvalinfo *vi;
 		
 		vi = (gii_cmddata_getvalinfo *) ev->cmd.data;
@@ -756,7 +757,7 @@ static int GII_spaceorb_sendevent(gii_input *inp, gii_event *ev)
 		return GII_spaceorb_sendvalinfo(inp, vi->number);
 	}
 
-	return -1;  /* Unknown command */
+	return GGI_EEVUNKNOWN;  /* Unknown command */
 }
 
 
@@ -774,6 +775,7 @@ static int GII_spaceorb_close(gii_input *inp)
 	return 0;
 }
 
+
 int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 {
 	int ret;
@@ -809,7 +811,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	inp->GIIseteventmask(inp, emKey | emValuator);
 
 	inp->maxfd = SPACEORB_HOOK(inp)->fd + 1;
-	FD_SET((SPACEORB_HOOK(inp)->fd), &inp->fdset);
+	FD_SET((unsigned)(SPACEORB_HOOK(inp)->fd), &inp->fdset);
 
 	/* Send initial cmdDevInfo event */
 	GII_spaceorb_senddevinfo(inp);
