@@ -1,4 +1,4 @@
-/* $Id: libtcp.c,v 1.5 2002/10/06 21:49:28 cegger Exp $
+/* $Id: libtcp.c,v 1.9.4.1 2004/11/14 13:10:43 cegger Exp $
 ******************************************************************************
 
    libtcp.c - functions to support GII events over TCP.
@@ -26,30 +26,52 @@
 */
 
 #include "config.h"
+
 #include <ggi/internal/gii-dl.h>
 #include <ggi/internal/gii_debug.h>
 #include "libtcp.h"
 
-#include <stdio.h>
-#include <string.h>
-#include <sys/types.h>
-#ifdef HAVE_SYS_SOCKET_H
-# include <sys/socket.h>
+#if defined(__WIN32__) && !defined(__CYGWIN__)
+#  ifdef HAVE_WINSOCK2_H
+#    include <winsock2.h>
+#  endif
+#  ifdef HAVE_WINSOCK_H
+#    include <winsock.h>
+#  endif
 #endif
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
+
+#ifdef HAVE_SYS_TYPES_H
+# include <sys/types.h>
 #endif
-#ifdef HAVE_ARPA_INET_H
-# include <arpa/inet.h>
-#endif
-#ifdef HAVE_NETDB_H
-# include <netdb.h>
+
+#if !defined(__WIN32__) || defined(__CYGWIN__)
+# ifdef HAVE_SYS_SOCKET_H
+#   include <sys/socket.h>
+# endif
+# ifdef HAVE_NETINET_IN_H
+#   include <netinet/in.h>
+# endif
+# ifdef HAVE_ARPA_INET_H
+#   include <arpa/inet.h>
+# endif
+# ifdef HAVE_NETDB_H
+#   include <netdb.h>
+# endif
 #endif
+
 #ifdef HAVE_SYS_UN_H
 # include <sys/un.h>
 #endif
 
 
+#include <stdio.h>
+#include <string.h>
+
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
+
+
 int
 _gii_tcp_htonev(gii_event *ev)
 {
@@ -94,7 +116,7 @@ _gii_tcp_htonev(gii_event *ev)
 		break;
 	default:
 		/* Unable to convert this event. */
-		return -1;
+		return GGI_EEVUNKNOWN;
 	}
 
 	return 0;
@@ -145,7 +167,7 @@ _gii_tcp_ntohev(gii_event *ev)
 		break;
 	default:
 		/* Unable to convert this event. */
-		return -1;
+		return GGI_EEVUNKNOWN;
 	}
 
 	return 0;
@@ -178,7 +200,7 @@ _gii_tcp_connect(gii_tcp_priv *priv, const char *host, int port)
 				fprintf(stderr,
 					"giitcp: Unknown address type: %d\n",
 					type);
-			return -1;
+			return GGI_ENOTFOUND;
 		}
 		memcpy(&in, hent->h_addr, sizeof(in));
 		ggUnlock(priv->lock);
@@ -187,19 +209,19 @@ _gii_tcp_connect(gii_tcp_priv *priv, const char *host, int port)
 #ifdef HAVE_INET_ATON
 		if (!inet_aton(host, &in)) {
 #else
-		if ((in.s_addr = inet_addr(host)) == -1) {
+		if ((signed)(in.s_addr = inet_addr(host)) == -1) {
 #endif
 			fprintf(stderr,
 				"giitcp: Unknown or invalid address: %s\n",
 				host);
-			return -1;
+			return GGI_EUNKNOWN;
 		}
 	}
 
 	sockfd = socket(AF_INET, SOCK_STREAM, 0);
 	if (sockfd < 0) {
 		perror("giitcp");
-		return -1;
+		return GGI_ENOFILE;
 	}
 
 	memset(&addr, 0, sizeof(addr));
@@ -208,7 +230,7 @@ _gii_tcp_connect(gii_tcp_priv *priv, const char *host, int port)
 	addr.sin_port = htons(port);
 	if (connect(sockfd, (struct sockaddr*)&addr, sizeof(addr)) != 0) {
 		perror("giitcp: connection failed");
-		return -1;
+		return GGI_ENODEVICE;
 	}
 	priv->fd = sockfd;
 	priv->state = GIITCP_CONNECTED;
@@ -226,7 +248,7 @@ _gii_tcp_listen(gii_tcp_priv *priv, int port)
 	sockfd = socket(AF_INET, SOCK_STREAM, 0);
 	if (sockfd < 0) {
 		perror("giitcp: unable to create socket");
-		return -1;
+		return GGI_ENODEVICE;
 	}
 
 	memset(&addr, 0, sizeof(addr));
@@ -236,13 +258,13 @@ _gii_tcp_listen(gii_tcp_priv *priv, int port)
 	if (bind(sockfd, (struct sockaddr*)&addr, sizeof(addr)) != 0) {
 		perror("giitcp: unable to bind socket");
 		_gii_tcp_close(sockfd);
-		return -1;
+		return GGI_ENODEVICE;
 	}
 
 	if (listen(sockfd, 1) != 0) {
 		perror("giitcp: unable to listen to socket");
 		_gii_tcp_close(sockfd);
-		return -1;
+		return GGI_ENODEVICE;
 	}
 
 	priv->listenfd = sockfd;
@@ -267,7 +289,7 @@ _gii_tcp_accept(gii_tcp_priv *priv)
 	fd = accept(priv->listenfd, (struct sockaddr *)&addr, &size);
 	if (fd < 0) {
 		perror("giitcp: unable to accept connection");
-		return -1;
+		return GGI_ENODEVICE;
 	}
 
 	priv->fd = fd;
@@ -280,7 +302,7 @@ _gii_tcp_accept(gii_tcp_priv *priv)
 int
 _gii_tcp_close(int fd)
 {
-#ifdef __WIN32__
+#if defined(__WIN32__) && !defined(__CYGWIN__)
 	return closesocket(fd);
 #else
 	return close(fd);
