@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.5.2.4 2004/05/01 21:41:16 cegger Exp $
+/* $Id$
 ******************************************************************************
 
    Standalone X inputlib
@@ -28,6 +28,7 @@
 #include "config.h"
 #include <ggi/internal/gii-dl.h>
 #include <ggi/internal/gii_debug.h>
+#include <ggi/internal/gii_target.h>
 #include "xev.h"
 
 #include <stdlib.h>
@@ -35,10 +36,9 @@
 #include <X11/Xlib.h>
 #include <ctype.h>
 
-
 static const gg_option optlist[] =
 {
-	{ "nokeyfocus",   "yes" }
+	{ "nokeyfocus",   "no" }
 };
 
 #define OPT_NOKEYFOCUS	0
@@ -104,7 +104,7 @@ static int do_grab(Display *disp, Window win, Cursor crsr)
 			 GrabModeAsync, GrabModeAsync, win, crsr, CurrentTime)
 	    != GrabSuccess) {
 		GIIDPRINT_LIBS("input-X: Unable to grab input\n");
-		return -1;
+		return GGI_ENODEVICE;
 	}
 
 	return 0;
@@ -190,6 +190,7 @@ static gii_event_mask GII_x_eventpoll(gii_input *inp, void *arg)
 				_giiEvQueueAdd(inp, &releasecache);
 				rc |= emKeyRelease;
 			}
+
 			_giiEventBlank(&releasecache, sizeof(gii_key_event));
 			releasecache.any.size = sizeof(gii_key_event);
 			releasecache.any.type = evKeyRelease;
@@ -272,7 +273,7 @@ static gii_event_mask GII_x_eventpoll(gii_input *inp, void *arg)
 				      giiev.pmove.x, giiev.pmove.y);
 			break;
 		}
-		}
+		}	/* switch */
 		switch(giiev.any.type) {
 		case evPtrButtonPress:
 		case evPtrButtonRelease:
@@ -344,7 +345,9 @@ static void send_devinfo(gii_input *inp, int dev)
 	gii_event ev;
 	gii_cmddata_getdevinfo *dinfo;
 	x_priv  *priv = X_PRIV(inp);
-	int size = sizeof(gii_cmd_nodata_event)+sizeof(gii_cmddata_getdevinfo);
+	size_t size;
+
+	size = sizeof(gii_cmd_nodata_event)+sizeof(gii_cmddata_getdevinfo);
 
 	_giiEventBlank(&ev, size);
 	
@@ -369,8 +372,7 @@ static void send_devinfo(gii_input *inp, int dev)
 }
 
 
-static int
-GIIsendevent(gii_input *inp, gii_event *ev)
+static int GIIsendevent(gii_input *inp, gii_event *ev)
 {
 	x_priv  *priv = X_PRIV(inp);
 	if ((ev->any.target & 0x100) != inp->origin &&
@@ -428,7 +430,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 		if (args == NULL) {
 			fprintf(stderr, "input-x: error in "
 				"arguments.\n");
-			return -1;
+			return GGI_EARGINVAL;
 		}
 	}
 
@@ -445,7 +447,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 		ButtonPressMask | ButtonReleaseMask | PointerMotionMask |
 		FocusChangeMask;
 	win = XCreateWindow(disp, RootWindow(disp, scr), 0, 0,
-			    WidthOfScreen(sc)/2,  HeightOfScreen(sc)/2,
+			    WidthOfScreen(sc)/2U,  HeightOfScreen(sc)/2U,
 			    0, 0, InputOnly, CopyFromParent,
 			    CWEventMask, &attr);
 
@@ -482,10 +484,9 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 
 	{
 		Window dummywin;
-		unsigned int w, h;
-		int dummy;
-		
-		XGetGeometry(disp, win, &dummywin, &dummy, &dummy,
+		unsigned int w, h, dummy;
+
+		XGetGeometry(disp, win, &dummywin, (int *)&dummy, (int *)&dummy,
 			     &w, &h, &dummy, &dummy);
 		priv->width = w;
 		priv->height = h;
@@ -518,7 +519,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	inp->targetcan = emKey | emPointer;
 	inp->curreventmask = emKey | emPointer;
 
-	if (tolower(options[OPT_NOKEYFOCUS].result[0]) != 'n') {
+	if (tolower(options[OPT_NOKEYFOCUS].result[0]) == 'n') {
 		priv->keyfocus = 1;
 	} else {
 		priv->keyfocus = 0;
@@ -541,7 +542,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	}
 
 	inp->maxfd = ConnectionNumber(disp) + 1;
-	FD_SET(ConnectionNumber(disp), &inp->fdset);
+	FD_SET((unsigned)(ConnectionNumber(disp)), &inp->fdset);
 
 	mouse_devinfo.num_buttons = XGetPointerMapping(priv->disp, NULL, 0);
 	XDisplayKeycodes(priv->disp, &minkey, &maxkey);
