@@ -1,4 +1,4 @@
-/* $Id: xev.c,v 1.2 2002/02/22 21:51:13 soyt Exp $
+/* $Id: xev.c,v 1.3 2004/06/05 00:47:58 aldot Exp $
 ******************************************************************************
 
    X to GII event conversion - implementation
@@ -716,6 +716,9 @@ int _gii_xev_trans(XKeyEvent *xev, gii_key_event *giiev,
 		case XLookupChars:
 			sym = *buf;
 			break;
+		case XBufferOverflow:
+			GIIDPRINT_CORE("can't fit %i bytes into buffer!\n", n);
+			break;
 		}
 	} else {
 		XLookupString(xev, NULL, 0, &xsym, compose_status);
